@@ -906,8 +906,13 @@ int cs_mount_permission(const char *dev_name, struct path *path,
 			const char *type, unsigned long flags,
 			void *data_page);
 int cs_pivot_root_permission(struct path *old_path, struct path *new_path);
+#if 1
 int cs_rename_permission(struct dentry *old_dentry, struct dentry *new_dentry,
 			 struct vfsmount *mnt);
+#else
+int cs_rename_permission(struct dentry *old_dentry, struct dentry *new_dentry,
+			 struct vfsmount *mnt, unsigned int flags);
+#endif
 int cs_symlink_permission(struct dentry *dentry, struct vfsmount *mnt,
 			  const char *from);
 int cs_truncate_permission(struct dentry *dentry, struct vfsmount *mnt);
