@@ -340,8 +340,13 @@ static char *cs_get_local_path(struct dentry *dentry, char * const buffer,
 		 * Use filesystem name if filesystems does not support rename()
 		 * operation.
 		 */
+#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 17, 0)
 		if (inode->i_op && !inode->i_op->rename)
 			goto prepend_filesystem_name;
+#else
+		if (!inode->i_op->rename && !inode->i_op->rename2)
+			goto prepend_filesystem_name;
+#endif
 	}
 	/* Prepend device name. */
 	{
@@ -445,6 +450,7 @@ char *cs_realpath(struct path *path)
 		 * or "path without vfsmount" or "absolute name is unavailable"
 		 * cases.
 		 */
+#if LINUX_VERSION_CODE < KERNEL_VERSION(3, 17, 0)
 		if (!path->mnt || (inode->i_op && !inode->i_op->rename))
 			pos = ERR_PTR(-EINVAL);
 		else {
@@ -456,6 +462,14 @@ char *cs_realpath(struct path *path)
 		if (pos == ERR_PTR(-EINVAL))
 			pos = cs_get_local_path(path->dentry, buf,
 						buf_len - 1);
+#else
+		if (!path->mnt ||
+		    (!inode->i_op->rename && !inode->i_op->rename2))
+			pos = cs_get_local_path(path->dentry, buf,
+						buf_len - 1);
+		else
+			pos = cs_get_absolute_path(path, buf, buf_len - 1);
+#endif
 encode:
 		if (IS_ERR(pos))
 			continue;
