@@ -1318,6 +1318,7 @@ static int cs_path_symlink(struct path *dir, struct dentry *dentry,
 	return original_security_ops.path_symlink(dir, dentry, old_name);
 }
 
+#if 1
 /**
  * cs_path_rename - Check permission for rename().
  *
@@ -1338,6 +1339,31 @@ static int cs_path_rename(struct path *old_dir, struct dentry *old_dentry,
 	return original_security_ops.path_rename(old_dir, old_dentry, new_dir,
 						 new_dentry);
 }
+#else
+/**
+ * cs_path_rename - Check permission for rename().
+ *
+ * @old_dir:    Pointer to "struct path".
+ * @old_dentry: Pointer to "struct dentry".
+ * @new_dir:    Pointer to "struct path".
+ * @new_dentry: Pointer to "struct dentry".
+ * @flags:      Rename flags.
+ *
+ * Returns 0 on success, negative value otherwise.
+ */
+static int cs_path_rename(struct path *old_dir, struct dentry *old_dentry,
+			  struct path *new_dir, struct dentry *new_dentry,
+			  unsigned int flags)
+{
+	int rc = cs_rename_permission(old_dentry, new_dentry, old_dir->mnt,
+				      flags);
+	if (rc)
+		return rc;
+	while (!original_security_ops.path_rename);
+	return original_security_ops.path_rename(old_dir, old_dentry, new_dir,
+						 new_dentry, flags);
+}
+#endif
 
 /**
  * cs_path_link - Check permission for link().
@@ -1667,6 +1693,7 @@ static int cs_inode_symlink(struct inode *dir, struct dentry *dentry,
 	return original_security_ops.inode_symlink(dir, dentry, old_name);
 }
 
+#if 1
 /**
  * cs_inode_rename - Check permission for rename().
  *
@@ -1687,6 +1714,30 @@ static int cs_inode_rename(struct inode *old_dir, struct dentry *old_dentry,
 	return original_security_ops.inode_rename(old_dir, old_dentry, new_dir,
 						  new_dentry);
 }
+#else
+/**
+ * cs_inode_rename - Check permission for rename().
+ *
+ * @old_dir:    Pointer to "struct inode".
+ * @old_dentry: Pointer to "struct dentry".
+ * @new_dir:    Pointer to "struct inode".
+ * @new_dentry: Pointer to "struct dentry".
+ * @flags:      Rename flags.
+ *
+ * Returns 0 on success, negative value otherwise.
+ */
+static int cs_inode_rename(struct inode *old_dir, struct dentry *old_dentry,
+			   struct inode *new_dir, struct dentry *new_dentry,
+			   unsigned int flags)
+{
+	int rc = cs_rename_permission(old_dentry, new_dentry, NULL, flags);
+	if (rc)
+		return rc;
+	while (!original_security_ops.inode_rename);
+	return original_security_ops.inode_rename(old_dir, old_dentry, new_dir,
+						  new_dentry, flags);
+}
+#endif
 
 /**
  * cs_inode_link - Check permission for link().
