@@ -1578,6 +1578,7 @@ int cs_truncate_permission(struct dentry *dentry, struct vfsmount *mnt)
 	return cs_path_perm(CS_MAC_TRUNCATE, dentry, mnt);
 }
 
+#if 1
 /**
  * cs_rename_permission - Check permission for vfs_rename().
  *
@@ -1593,6 +1594,29 @@ int cs_rename_permission(struct dentry *old_dentry, struct dentry *new_dentry,
 	return cs_path2_perm(CS_MAC_RENAME, old_dentry, mnt, new_dentry,
 			     mnt);
 }
+#else
+/**
+ * cs_rename_permission - Check permission for vfs_rename().
+ *
+ * @old_dentry: Pointer to "struct dentry".
+ * @new_dentry: Pointer to "struct dentry".
+ * @mnt:        Pointer to "struct vfsmount". Maybe NULL.
+ * @flags:      Rename flags.
+ *
+ * Returns 0 on success, negative value otherwise.
+ */
+static int __ccs_rename_permission(struct dentry *old_dentry,
+				   struct dentry *new_dentry,
+				   struct vfsmount *mnt, unsigned int flags)
+{
+	int err = cs_path2_perm(CS_MAC_RENAME, old_dentry, mnt, new_dentry,
+				mnt);
+	if (!err && (flags & RENAME_EXCHANGE))
+		err = cs_path2_perm(CS_MAC_RENAME, new_dentry, mnt, old_dentry,
+				    mnt);
+	return err;
+}
+#endif
 
 /**
  * cs_link_permission - Check permission for vfs_link().
